#define _CONFIG_H

#include <stdlib.h>
#include <stdint.h>
#include <errno.h>
#include <fcntl.h>
#include <sys/stat.h>
#include <sys/uio.h>

#include <glusterfs/logging.h>
#include <glusterfs/api/glfs.h>
#include <glusterfs/api/glfs-handles.h>

int main(void) {
    glfs_t *fs = glfs_new("gvdata00");
    if (fs == NULL) {
        perror("Unable to create virtual mount");
        goto exit;
    }

    if (glfs_set_logging(fs, "/var/log/libgfapi.log", 2)) {
        perror("Unable to set virtual mount logging");
        goto exit;
    }

    if (glfs_set_volfile_server(fs, "tcp", "127.0.0.1", 0)) {
        perror("Unable to set virtual mount volfile server");
        goto exit;
    }

    if (glfs_init(fs)) {
        perror("Unable to init virtual mount");
        goto exit;
    }

    glfs_fd_t *fd = glfs_open(fs, "/test", O_RDONLY);
    if (fd == NULL) {
        perror("Unable to open file descriptor");
        goto exit;
    }

    uint8_t buff[8193];
    int read = glfs_read(fd, buff, 8192, 0);
    if (read < 0) {
        perror("Unable to read from file descriptor");
        goto exit;
    }

    buff[read] = '\0';
    printf("Data: %s\n", buff);

exit:
    if (fd != NULL && glfs_close(fd)) {
        perror("Unable close file descriptor");
    }

    if (fs != NULL && glfs_fini(fs)) {
        perror("Unable to close virtual mount");
    }
    
    exit(errno);
}
